# -*- coding: utf-8 -*-

from django.conf.urls import url

from thux.txcms import models
from . import views


def get_urlpatterns():
    url_patterns = []
    for cls in models.Plugin.get_related_models():
        # create url to GenericListAPIView
        url_pattern = url(
            r'^{}_list'.format(cls._meta.model_name),
            views.GenericListAPIView.as_view(),
            kwargs={'model': cls},
            name='txcms_api_{}_list'.format(cls._meta.model_name)
        )
        url_patterns.append(url_pattern)

        # create url to GenericCreateAPIView
        url_pattern = url(
            r'^{}_create'.format(cls._meta.model_name),
            views.GenericCreateAPIView.as_view(),
            kwargs={'model': cls},
            name='txcms_api_{}_create'.format(cls._meta.model_name)
        )
        url_patterns.append(url_pattern)

        # create url to GenericUpdateAPIView
        url_pattern = url(
            r'^{}_update'.format(cls._meta.model_name),
            views.GenericUpdateAPIView.as_view(),
            kwargs={'model': cls},
            name='txcms_api_{}_update'.format(cls._meta.model_name)
        )
        url_patterns.append(url_pattern)

    return url_patterns

urlpatterns = get_urlpatterns()

urlpatterns += [
    url(
        r'^page/$',
        views.PageList.as_view(),
        name='page_list'
    ),
    url(
        r'^nav/$',
        views.NavList.as_view(),
        name='nav_list'
    ),
    url(
        r'^page_language/$',
        views.PageLanguageList.as_view(),
        name='page_language_list'
    ),
    url(
        r'^page_language/(?P<slug>[\w-]+)/retrieve/$',
        views.PageLanguageRetrieve.as_view(),
        name='page_language_retrieve'
    ),
    url(
        r'^page_language_with_plugins/(?P<slug>[\w-]+)/retrieve/$',
        views.PageLanguagePluginsRetrieve.as_view(),
        name='page_language_with_plugins'
    ),
    url(
        r'^plugin/$',
        views.PluginList.as_view(),
        name='plugin_list'
    ),
    url(
        r'^plugin/(?P<pk>\d+)/retrieve/$',
        views.PluginRetrieve.as_view(),
        name='plugin_retrieve'
    ),
]
