# -*- coding: utf-8 -*-

from rest_framework import generics
from rest_framework import permissions

from . import serializers
from .. import models


class GenericListAPIView(generics.ListAPIView):
    def __init__(self, **kwargs):
        self.model = None
        super(GenericListAPIView, self).__init__(**kwargs)

    def dispatch(self, request, *args, **kwargs):
        self.model = kwargs['model']
        return super(GenericListAPIView, self).dispatch(request, *args, **kwargs)

    def get_queryset(self):
        return self.model.objects.all()

    def get_serializer(self, *args, **kwargs):
        serializer_class = self.get_serializer_class()
        kwargs['context'] = self.get_serializer_context()
        kwargs['model'] = self.model
        return serializer_class(*args, **kwargs)

    def get_serializer_class(self):
        return serializers.GenericSerializer


class GenericCreateAPIView(generics.CreateAPIView):
    def __init__(self, **kwargs):
        self.model = None
        super(GenericCreateAPIView, self).__init__(**kwargs)

    def dispatch(self, request, *args, **kwargs):
        self.model = kwargs['model']
        return super(GenericCreateAPIView, self).dispatch(request, *args, **kwargs)

    def get_queryset(self):
        return self.model.objects.all()

    def get_serializer(self, *args, **kwargs):
        serializer_class = self.get_serializer_class()
        kwargs['context'] = self.get_serializer_context()
        kwargs['model'] = self.model
        return serializer_class(*args, **kwargs)

    def get_serializer_class(self):
        return serializers.GenericSerializer


class GenericUpdateAPIView(generics.UpdateAPIView):
    def __init__(self, **kwargs):
        self.model = None
        super(GenericUpdateAPIView, self).__init__(**kwargs)

    def dispatch(self, request, *args, **kwargs):
        self.model = kwargs['model']
        return super(GenericUpdateAPIView, self).dispatch(request, *args, **kwargs)

    def get_queryset(self):
        return self.model.objects.all()

    def get_serializer(self, *args, **kwargs):
        serializer_class = self.get_serializer_class()
        kwargs['context'] = self.get_serializer_context()
        kwargs['model'] = self.model
        return serializer_class(*args, **kwargs)

    def get_serializer_class(self):
        return serializers.GenericSerializer


class GenericRetrieveAPIView(generics.RetrieveAPIView):
    def __init__(self, **kwargs):
        self.model = None
        super(GenericRetrieveAPIView, self).__init__(**kwargs)

    def dispatch(self, request, *args, **kwargs):
        self.model = kwargs['model']
        return super(GenericRetrieveAPIView, self).dispatch(request, *args, **kwargs)

    def get_queryset(self):
        return self.model.objects.all()

    def get_serializer(self, *args, **kwargs):
        serializer_class = self.get_serializer_class()
        kwargs['context'] = self.get_serializer_context()
        kwargs['model'] = self.model
        return serializer_class(*args, **kwargs)

    def get_serializer_class(self):
        return serializers.GenericSerializer


class PageList(generics.ListAPIView):
    queryset = models.Page.objects.all()
    serializer_class = serializers.PageSerializer


class NavList(generics.ListAPIView):
    queryset = models.Nav.objects.all()
    serializer_class = serializers.NavSerializer


class PageLanguageList(generics.ListAPIView):
    queryset = models.PageLanguage.objects.all()
    serializer_class = serializers.PageLanguageSerializer


class PageLanguageRetrieve(generics.RetrieveAPIView):
    permission_classes = (permissions.AllowAny,)
    lookup_field = 'slug'
    queryset = models.PageLanguage.objects.all()
    serializer_class = serializers.PageLanguageSerializer


class PageLanguagePluginsRetrieve(generics.RetrieveAPIView):
    permission_classes = (permissions.AllowAny,)
    lookup_field = 'slug'
    queryset = models.PageLanguage.objects.all()
    serializer_class = serializers.PageLanguagePluginsSerializer


class PluginList(generics.ListAPIView):
    queryset = models.Plugin.objects.all()
    serializer_class = serializers.PluginSerializer


class PluginRetrieve(generics.RetrieveAPIView):
    queryset = models.Plugin.objects.all()
    serializer_class = serializers.PluginSerializerRetrieve
