# -*- coding: utf-8 -*-

import admin_tools

from django.utils.translation import ugettext_lazy as _

from admin_tools.dashboard import modules, AppIndexDashboard

from jmb.core.admin import dashboard as jmb_dashboard

from .models import Plugin, AbstractItemModel


def get_plugin_models():
    model_list = []
    for model in Plugin.get_related_models():
        model_list.append('{}.{}'.format(
            model.__module__, model.__name__
        ))
    return model_list


def get_item_models():
    model_list = []
    for model in AbstractItemModel.get_related_models():
        model_list.append('{}.{}'.format(
            model.__module__, model.__name__
        ))
    return model_list


class DefaultDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("TX CMS"),
            'display': "tabs",
            'children': (Models(), PluginModels(), ItemModels())
        })
        super(DefaultDashboard, self).__init__(**kwargs)


class AppDashboard(modules.Group):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("TX CMS"),
            'display': "tabs",
            'children': (Models(), PluginModels(), ItemModels())
        })
        super(AppDashboard, self).__init__(**kwargs)


class Models(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({
            'title': _("Page Language"),
            'models': (
                'django.contrib.sites.models.Site',
                'thux.txcms.models.PageLanguage',
                'thux.txcms.models.Plugin',
            ),
        })
        super(Models, self).__init__(**kwargs)


class PluginModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({'title': _("TX Plugins"), 'models': '---'})
        if get_plugin_models():
            kwargs['models'] = get_plugin_models()
        super(PluginModels, self).__init__(**kwargs)


class ItemModels(modules.ModelList):
    def __init__(self, **kwargs):
        kwargs.update({'title': _("TX ItemModels"), 'models': '---'})
        if get_item_models():
            kwargs['models'] = get_item_models()
        super(ItemModels, self).__init__(**kwargs)


class DefaultAppDashboard(AppIndexDashboard):
    def __init__(self, app_title, models, **kwargs):
        AppIndexDashboard.__init__(self, app_title, models, **kwargs)
        self.columns = 3

    def init_with_context(self, context):
        self.children.append(
            DefaultDashboard(),
        )


# Used in /admin
jmb_dashboard.register_group(AppDashboard, 'thux.txcms')
# Used in /admin/order
admin_tools.dashboard.register(DefaultAppDashboard, 'thux.txcms')
