# -*- coding: utf-8 -*-

from django.core.urlresolvers import reverse
from django.utils.translation import ugettext as _

from admin_tools.menu import items

from jmb.core.admin.menu import register_menu

from .utils import get_related_models, get_related_item_models


def get_children():
    children = [
        items.MenuItem(_('add site'), reverse('admin:sites_site_add', )),
        items.MenuItem(_('sites list'), reverse('admin:sites_site_changelist', )),
        items.MenuItem(_('add page language'), reverse('admin:txcms_pagelanguage_add', )),
        items.MenuItem(_('page language list'), reverse('admin:txcms_pagelanguage_changelist', )),
        items.MenuItem(_('plugin list'), reverse('admin:txcms_plugin_changelist', )),
    ]
    return children


def get_children_plugin():
    children = []
    for plugin in get_related_models().items():
        values = plugin[1]
        children.append(
            items.MenuItem(
                _('{}'.format(values['verbose_name'])),
                reverse('admin:{}_{}_changelist'.format(values['app_label'], values['model_name']),),
                children=[
                    items.MenuItem(
                        _('add {}'.format(values['verbose_name'])),
                        reverse('admin:{}_{}_add'.format(values['app_label'], values['model_name']),)
                    ),
                    items.MenuItem(
                        _('{} list'.format(values['verbose_name'])),
                        reverse('admin:{}_{}_changelist'.format(values['app_label'], values['model_name']),)
                    ),
                ]
            )
        )
    return children


def get_children_item():
    children = []
    for plugin in get_related_item_models().items():
        values = plugin[1]
        children.append(
            items.MenuItem(
                _('{}'.format(values['verbose_name'])),
                reverse('admin:{}_{}_changelist'.format(values['app_label'], values['model_name']),),
                children=[
                    items.MenuItem(
                        _('add {}'.format(values['verbose_name'])),
                        reverse('admin:{}_{}_add'.format(values['app_label'], values['model_name']),)
                    ),
                    items.MenuItem(
                        _('{} list'.format(values['verbose_name'])),
                        reverse('admin:{}_{}_changelist'.format(values['app_label'], values['model_name']),)
                    ),
                ]
            )
        )
    return children


menu_item = items.MenuItem(
    _('TX CMS'),
    reverse('admin:app_list', kwargs={'app_label': 'txcms'}),
    children=get_children(),
)

menu_item_plugin = items.MenuItem(
    _('TX PLUGIN'),
    children=get_children_plugin(),
)

menu_item_item = items.MenuItem(
    _('TX ITEM'),
    children=get_children_item()
)

register_menu(menu_item, 'thux.txcms')
register_menu(menu_item_plugin, 'thux.txplugin')
register_menu(menu_item_item, 'thux.txitem')
