# -*- coding: utf-8 -*-
"""
helper module for thux.txcms
"""

import logging

from collections import OrderedDict

from django.conf import settings

from .models import Plugin, Nav, AbstractItemModel


logger = logging.getLogger('jmb.app_label')


def get_related_models():
    """
    Return all children Plugin models
    Use in dashboard, jmenu and admin.PluginAdmin
    """
    model_dict = OrderedDict()
    plugins = Plugin.get_related_models()
    # order plugin list
    plugins = sorted(plugins, key=lambda plugin: plugin._meta.model_name)
    for model in plugins:
        mm = model._meta
        model_dict[mm.model_name] = dict(
            app_label=mm.app_label, model_name=mm.model_name,
            model=mm.model, object_name=mm.object_name, verbose_name=mm.verbose_name,
        )
    return model_dict


def get_navs(language=settings.LANGUAGE_CODE, is_superuser=False):
    """
    Return dicttionary of nav: key=nav and value=queryset of page_languages
    """
    nav_dict = OrderedDict()
    navs = Nav.objects.all().order_by('name')
    for nav in navs:
        if is_superuser:
            nav_dict[nav.slug] = nav.page_languages.filter(status__gte=1, language=language)
        else:
            nav_dict[nav.slug] = nav.page_languages.filter(status=1, language=language)
    return nav_dict


def get_related_item_models():
    """
    Return all children AbstractItemModel models
    Use in dashboard, jmenu and admin.PluginAdmin
    """
    model_dict = OrderedDict()
    items = AbstractItemModel.get_related_models()
    # order plugin list
    items = sorted(items, key=lambda item: item._meta.model_name)
    for model in items:
        mm = model._meta
        model_dict[mm.model_name] = dict(
            app_label=mm.app_label, model_name=mm.model_name,
            model=mm.model, object_name=mm.object_name, verbose_name=mm.verbose_name,
        )
    return model_dict
